#include <iostream>
#include <string>
#include <vector>
#include <map>
#include <math.h>
#include <algorithm>
#include <iomanip>

using namespace std;
#define int long long
#define pii pair<int, int>
#define vec vector

void imin(int& a, int b) {a = min(a, b);}

int inf = 1000000005;

struct DisjointSparseTable {
    int ff(int e, int p = -inf) {return max(e, p);}
    vec<vec<int>> st;
    vec<int> logs;
    void build(vec<int> a, int n) {
        int len = 1;
        while((1ll << len) < n) len++;
        a.resize((1ll << len), 0);
        logs.resize((1ll << len), 0);
        st = vec<vec<int>> (len + 1, vec<int>(1ll << len));
        st[0][0] = a[0];
        for(int i = 1; i < (1ll << len); i++) {
            logs[i] = log2(i);
            st[0][i] = ff(a[i]);
        }
        for(int h = 1; h < len; h++) {
            int tlen = (1ll << h);
            for(int c = tlen; c < (1ll << len); c += 2 * tlen) {
                st[h][c] = a[c];
                for(int i = c + 1; i < c + tlen; i++) {
                    st[h][i] = ff(st[h][i - 1], a[i]);
                }
                st[h][c - 1] = a[c - 1];
                for(int i = c- 2; i >= c - tlen; i--) {
                    st[h][i] = ff(st[h][i + 1], a[i]);
                }
            }
        }
    }
    int ans(int l, int r) {
        if(l == r) return ff(st[0][l]);
        int row = logs[l ^ r];
        return ff(st[row][l], st[row][r]);
    }
};

vec<int> dp;
vec<int> t;

void build(int v, int l, int r) {
    if(l + 1 == r) {
        t[v] = dp[l];
        return;
    }
    int m = (l + r) / 2 ;
    build(v * 2, l, m);
    build(v * 2 + 1, m, r);
    t[v] = min(t[v * 2], t[v * 2 + 1]);
}

void update(int v, int l, int r, int id, int val) {
    if(l + 1 == r) {
        t[v] = dp[l] = val;
        return;
    }
    int m = (l + r) / 2;
    if(id < m) update(v * 2, l, m, id, val);
    else update(v * 2 + 1, m, r, id, val);
    t[v] = min(t[v * 2], t[v * 2 + 1]);
}

int get_min(int v, int l, int r, int ql, int qr) {
    if(ql <= l && r <= qr) {
        return t[v];
    }
    if(ql >= r || l >= qr) {
        return inf;
    }
    int m = (l + r) / 2;
    return min(get_min(v * 2, l, m, ql, qr), get_min(v * 2 + 1, m, r, ql, qr));
}


signed main() {
	ios::sync_with_stdio(0); cin.tie(0); cout.tie(0);
    int n; cin >> n;
    vec<int> h(n), c(n);
    for(int &i : h) cin >> i;
    for(int &i : c) cin >> i;
    if(n == 1) {
        cout << c[0];
        return 0;
    }
    DisjointSparseTable disp;
    disp.build(h, n);
    vec<int> left_max(n, -1);
    vec<int> right_max(n, n - 1);
    for(int i = 0; i < n; i++) {
        int l = 0;
        int r = i;
        while(l < r) {
            int m = (r + l) / 2;
            if(disp.ans(m, i) > h[i]) {
                l = m + 1;
            } else {
                r = m;
            }
        }
        left_max[i] = l;
    }
    for(int i = 0; i < n; i++) {
        int l = i;
        int r = n;
        while(r - l > 1) {
            int m = (r + l) / 2;
            if(disp.ans(i, m) > h[i]) {
                r = m;
            } else {
                l = m;
            }
        }
        right_max[i] = l;
    }
    dp = vec<int>(n, inf);
    t = vec<int>(n * 4, inf);
    dp[0] = c[0];
    imin(dp[right_max[1]], dp[0] + c[1]);
    build(1, 0, n);
    for(int i = 1; i < n; i++) {
        int qq = min(dp[i - 1] + c[i], dp[i]);
        if(disp.ans(0, i) == h[i]) {
            imin(qq, c[i]);
        }
        if(disp.ans(0, i) == h[0]) {
            imin(qq, c[0]);
        }
        int xx = left_max[i];
        if(xx != 0) xx--;
        imin(qq, get_min(1, 0, n, xx, i) + c[i]);
        if(i != n - 1) imin(qq, get_min(1, 0, n, i + 1, n));
        update(1, 0, n, i, qq);
        if(i != n - 1) {
            int id = right_max[i + 1];
            if (dp[id] > dp[i] + c[i + 1]) {
                update(1, 0, n, id, dp[i] + c[i + 1]);
            }
        }
    }
    cout << dp[n - 1];
}